Index: build_tools/jenkins_linux_pylint.sh
===================================================================
--- build_tools/jenkins_linux_pylint.sh	(revision 9939b1603283b7b9a863d258a9b0e17efc66c378)
+++ build_tools/jenkins_linux_pylint.sh	(revision 3a39c2e89f90377b2d15fa13b9ba9cf3b4144070)
@@ -14,3 +14,3 @@
 rm -f test/*.txt
 
-$PYLINT --rcfile "$WORKSPACE/build_tools/pylint.rc" -f parseable sasview-install/sasview.egg/sans sansview > test/sansview.txt || exit 0
+$PYLINT --rcfile "$WORKSPACE/build_tools/pylint.rc" -f parseable sasview-install/sasview.egg/sas sasview > test/sasview.txt || exit 0
Index: build_tools/jenkins_linux_test.sh
===================================================================
--- build_tools/jenkins_linux_test.sh	(revision 21b7a4932db1789027ff270369adb3d1062cd108)
+++ build_tools/jenkins_linux_test.sh	(revision 3a39c2e89f90377b2d15fa13b9ba9cf3b4144070)
@@ -12,3 +12,3 @@
 export PYTHONPATH=$PYTHONPATH:$WORKSPACE/sasview-install:$WORKSPACE/utils
 
-$PYTHON utest_sansview.py
+$PYTHON utest_sasview.py
Index: build_tools/jenkins_rhel6_build.sh
===================================================================
--- build_tools/jenkins_rhel6_build.sh	(revision b44da61a239ee4a55c1d720f76337b03cd633e85)
+++ build_tools/jenkins_rhel6_build.sh	(revision 3a39c2e89f90377b2d15fa13b9ba9cf3b4144070)
@@ -54,5 +54,5 @@
 #  Run tests
 cd $WORKSPACE/test
-python utest_sansview.py
+python utest_sasview.py
 
 
@@ -66,8 +66,8 @@
 cd ${WORKSPACE}/build_tools/rpm
 python create_rpm_spec.py ${SVN_REVISION}
-cp sansview.spec ${HOME}/rpmbuild/SPECS
+cp sasview.spec ${HOME}/rpmbuild/SPECS
 
 cd ${HOME}/rpmbuild/SPECS
-rpmbuild -bb sansview.spec --clean
+rpmbuild -bb sasview.spec --clean
 cp ${HOME}/rpmbuild/RPMS/x86_64/* ${WORKSPACE}/dist
 
Index: build_tools/jenkins_win32_build.bat
===================================================================
--- build_tools/jenkins_win32_build.bat	(revision b44da61a239ee4a55c1d720f76337b03cd633e85)
+++ build_tools/jenkins_win32_build.bat	(revision 3a39c2e89f90377b2d15fa13b9ba9cf3b4144070)
@@ -9,20 +9,20 @@
 %PYTHON% check_packages.py
 
-set PYTHONPATH=%WORKSPACE%\sansview-install;%PYTHONPATH%
+set PYTHONPATH=%WORKSPACE%\sasview-install;%PYTHONPATH%
 
-RD /S /Q sansview-install
-MD sansview-install
+RD /S /Q sasview-install
+MD sasview-install
 RD /S /Q dist
 RD /S /Q build
 
-rem %PYTHON% -m pip install -t ../sansview-install --no-deps bumps=0.7.5.4
-rem PYTHON% -m pip install -t ../sansview-install --no-deps periodictable=1.3.0
-rem %PYTHON% -m pip install -t ../sansview-install --no-deps pyparsing=1.5.5
+rem %PYTHON% -m pip install -t ../sasview-install --no-deps bumps=0.7.5.4
+rem PYTHON% -m pip install -t ../sasview-install --no-deps periodictable=1.3.0
+rem %PYTHON% -m pip install -t ../sasview-install --no-deps pyparsing=1.5.5
 
 %PYTHON% setup.py build -cmingw32
 %PYTHON% setup.py bdist_egg --skip-build
 cd dist
-%EASY_INSTALL% -d ..\sansview-install sasview*.egg
+%EASY_INSTALL% -d ..\sasview-install sasview*.egg
 
 cd %WORKSPACE%\test
-%PYTHON% utest_sansview.py
+%PYTHON% utest_sasview.py
Index: build_tools/rpm/create_rpm_spec.py
===================================================================
--- build_tools/rpm/create_rpm_spec.py	(revision f6f0c7b788892b608f4be47373ac2a43a8da6adf)
+++ build_tools/rpm/create_rpm_spec.py	(revision 3a39c2e89f90377b2d15fa13b9ba9cf3b4144070)
@@ -29,6 +29,6 @@
     return newline
 
-input=open("sansview.spec.template",'r')
-output=open("sansview.spec",'w')
+input=open("sasview.spec.template",'r')
+output=open("sasview.spec",'w')
 
 buf = input.read()

Index: build_tools/get_version.py
===================================================================
--- build_tools/get_version.py	(revision 5709051a16febce00b286288e9681dc40db38534)
+++ build_tools/get_version.py	(revision 3a39c2e89f90377b2d15fa13b9ba9cf3b4144070)
@@ -15,12 +15,12 @@
         return __revision__
 
 # Get the version number from the sansview module
 # Check to see if we are dealing with a release
 try:
-    import sans.sansview
-    __version__ = sans.sansview.__version__
-    __revision__ = sans.sansview.__build__
+    import sas.sasview
+    __version__ = sas.sasview.__version__
+    __revision__ = sas.sasview.__build__
 except:
-    print "Could not load sansview module"
+    print "Could not load sasview module"
 
 # Get actual revision number if possible
@@ -15,12 +15,12 @@
         return __revision__
 
-# Get the version number from the sansview module
+# Get the version number from the sasview module
 # Check to see if we are dealing with a release
 try: